@@ -12,10 +12,18 @@ from ._auto_db_schema import AutoProcProgram, AutoProcScaling, ProcessingJob
 
 logger = logging.getLogger("ispyb.sqlalchemy")
 
-AutoProcProgram.AutoProcProgramAttachments = relationship("AutoProcProgramAttachment")
-AutoProcScaling.AutoProcScalingStatistics = relationship("AutoProcScalingStatistics")
-ProcessingJob.ProcessingJobParameters = relationship("ProcessingJobParameter")
-ProcessingJob.ProcessingJobImageSweeps = relationship("ProcessingJobImageSweep")
+AutoProcProgram.AutoProcProgramAttachments = relationship(
+    "AutoProcProgramAttachment", back_populates="AutoProcProgram"
+)
+AutoProcScaling.AutoProcScalingStatistics = relationship(
+    "AutoProcScalingStatistics", back_populates="AutoProcScaling"
+)
+ProcessingJob.ProcessingJobParameters = relationship(
+    "ProcessingJobParameter", back_populates="ProcessingJob"
+)
+ProcessingJob.ProcessingJobImageSweeps = relationship(
+    "ProcessingJobImageSweep", back_populates="ProcessingJob"
+)
 
 
 def url(credentials=None) -> str:
